/* properties-page-widget.c generated by valac 0.26.0.50-d9a75, the Vala compiler
 * generated from properties-page-widget.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include <stdlib.h>
#include <string.h>


#define BOXES_TYPE_PROPERTIES_PAGE_WIDGET (boxes_properties_page_widget_get_type ())
#define BOXES_PROPERTIES_PAGE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_PAGE_WIDGET, BoxesPropertiesPageWidget))
#define BOXES_PROPERTIES_PAGE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_PAGE_WIDGET, BoxesPropertiesPageWidgetClass))
#define BOXES_IS_PROPERTIES_PAGE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_PAGE_WIDGET))
#define BOXES_IS_PROPERTIES_PAGE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_PAGE_WIDGET))
#define BOXES_PROPERTIES_PAGE_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_PAGE_WIDGET, BoxesPropertiesPageWidgetClass))

typedef struct _BoxesPropertiesPageWidget BoxesPropertiesPageWidget;
typedef struct _BoxesPropertiesPageWidgetClass BoxesPropertiesPageWidgetClass;
typedef struct _BoxesPropertiesPageWidgetPrivate BoxesPropertiesPageWidgetPrivate;

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

struct _BoxesPropertiesPageWidget {
	GtkBox parent_instance;
	BoxesPropertiesPageWidgetPrivate * priv;
	gboolean empty;
};

struct _BoxesPropertiesPageWidgetClass {
	GtkBoxClass parent_class;
};

struct _BoxesPropertiesPageWidgetPrivate {
	GtkGrid* grid;
	GList* properties;
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;


static gpointer boxes_properties_page_widget_parent_class = NULL;

GType boxes_properties_page_widget_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
#define BOXES_PROPERTIES_PAGE_WIDGET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_PROPERTIES_PAGE_WIDGET, BoxesPropertiesPageWidgetPrivate))
enum  {
	BOXES_PROPERTIES_PAGE_WIDGET_DUMMY_PROPERTY
};
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
BoxesPropertiesPageWidget* boxes_properties_page_widget_new (BoxesPropertiesPage page, BoxesMachine* machine);
BoxesPropertiesPageWidget* boxes_properties_page_widget_construct (GType object_type, BoxesPropertiesPage page, BoxesMachine* machine);
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GList* boxes_machine_get_properties (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
const gchar* boxes_property_get_description (BoxesProperty* self);
GtkWidget* boxes_property_get_widget (BoxesProperty* self);
GtkWidget* boxes_property_get_extra_widget (BoxesProperty* self);
static void _____lambda38_ (BoxesPropertiesPageWidget* self);
static void ______lambda38__boxes_property_refresh_properties (BoxesProperty* _sender, gpointer self);
gboolean boxes_properties_page_widget_flush_changes (BoxesPropertiesPageWidget* self);
void boxes_property_flush (BoxesProperty* self);
gboolean boxes_property_get_reboot_required (BoxesProperty* self);
static void boxes_properties_page_widget_finalize (GObject* obj);


static void _g_object_unref0_ (gpointer var) {
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 122 "properties-page-widget.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	g_list_free (self);
#line 131 "properties-page-widget.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	return self ? g_object_ref (self) : NULL;
#line 138 "properties-page-widget.c"
}


static void _____lambda38_ (BoxesPropertiesPageWidget* self) {
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	g_signal_emit_by_name (self, "refresh-properties");
#line 145 "properties-page-widget.c"
}


static void ______lambda38__boxes_property_refresh_properties (BoxesProperty* _sender, gpointer self) {
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_____lambda38_ ((BoxesPropertiesPageWidget*) self);
#line 152 "properties-page-widget.c"
}


BoxesPropertiesPageWidget* boxes_properties_page_widget_construct (GType object_type, BoxesPropertiesPage page, BoxesMachine* machine) {
	BoxesPropertiesPageWidget * self = NULL;
	BoxesPropertiesPage _tmp0_ = 0;
	GtkStyleContext* _tmp5_ = NULL;
	GtkStyleContext* _tmp6_ = NULL;
	GtkGrid* _tmp7_ = NULL;
	GtkGrid* _tmp8_ = NULL;
	GtkGrid* _tmp9_ = NULL;
	GtkGrid* _tmp10_ = NULL;
	GtkGrid* _tmp11_ = NULL;
	GtkScrolledWindow* scrolled_win = NULL;
	GtkScrolledWindow* _tmp12_ = NULL;
	GtkScrolledWindow* _tmp13_ = NULL;
	GtkScrolledWindow* _tmp14_ = NULL;
	GtkScrolledWindow* _tmp15_ = NULL;
	GtkScrolledWindow* _tmp16_ = NULL;
	GtkGrid* _tmp17_ = NULL;
	GtkScrolledWindow* _tmp18_ = NULL;
	PropertyCreationFlag flags = 0;
	BoxesMachine* _tmp19_ = NULL;
	BoxesPropertiesPage _tmp20_ = 0;
	GList* _tmp21_ = NULL;
	GList* _tmp22_ = NULL;
	guint _tmp23_ = 0U;
	gboolean _tmp24_ = FALSE;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	self = (BoxesPropertiesPageWidget*) g_object_new (object_type, NULL);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp0_ = page;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	switch (_tmp0_) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
		case BOXES_PROPERTIES_PAGE_GENERAL:
#line 191 "properties-page-widget.c"
		{
			const gchar* _tmp1_ = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			_tmp1_ = _ ("General");
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			gtk_widget_set_name ((GtkWidget*) self, _tmp1_);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			break;
#line 200 "properties-page-widget.c"
		}
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
		case BOXES_PROPERTIES_PAGE_SYSTEM:
#line 204 "properties-page-widget.c"
		{
			const gchar* _tmp2_ = NULL;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			_tmp2_ = _ ("System");
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			gtk_widget_set_name ((GtkWidget*) self, _tmp2_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			break;
#line 213 "properties-page-widget.c"
		}
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
		case BOXES_PROPERTIES_PAGE_DEVICES:
#line 217 "properties-page-widget.c"
		{
			const gchar* _tmp3_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			_tmp3_ = _ ("Devices");
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			gtk_widget_set_name ((GtkWidget*) self, _tmp3_);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			break;
#line 226 "properties-page-widget.c"
		}
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
		case BOXES_PROPERTIES_PAGE_SNAPSHOTS:
#line 230 "properties-page-widget.c"
		{
			const gchar* _tmp4_ = NULL;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			_tmp4_ = _ ("Snapshots");
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			gtk_widget_set_name ((GtkWidget*) self, _tmp4_);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			break;
#line 239 "properties-page-widget.c"
		}
		default:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
		break;
#line 244 "properties-page-widget.c"
	}
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp5_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	gtk_style_context_add_class (_tmp5_, "content-bg");
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp6_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	gtk_style_context_add_class (_tmp6_, "transparent-bg");
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp7_ = (GtkGrid*) gtk_grid_new ();
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	g_object_ref_sink (_tmp7_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_g_object_unref0 (self->priv->grid);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	self->priv->grid = _tmp7_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp8_ = self->priv->grid;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	g_object_set ((GtkWidget*) _tmp8_, "margin", 20, NULL);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp9_ = self->priv->grid;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	gtk_grid_set_row_spacing (_tmp9_, 10);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp10_ = self->priv->grid;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	gtk_grid_set_column_spacing (_tmp10_, 20);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp11_ = self->priv->grid;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp11_, GTK_ALIGN_START);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp12_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	g_object_ref_sink (_tmp12_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	scrolled_win = _tmp12_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp13_ = scrolled_win;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	gtk_widget_set_margin_start ((GtkWidget*) _tmp13_, 20);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp14_ = scrolled_win;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	gtk_widget_set_margin_end ((GtkWidget*) _tmp14_, 20);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp15_ = scrolled_win;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	gtk_scrolled_window_set_policy (_tmp15_, GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp16_ = scrolled_win;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp17_ = self->priv->grid;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	gtk_container_add ((GtkContainer*) _tmp16_, (GtkWidget*) _tmp17_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp18_ = scrolled_win;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	gtk_box_pack_end ((GtkBox*) self, (GtkWidget*) _tmp18_, TRUE, TRUE, (guint) 0);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	flags = PROPERTY_CREATION_FLAG_NONE;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp19_ = machine;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp20_ = page;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp21_ = boxes_machine_get_properties (_tmp19_, _tmp20_, &flags);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	__g_list_free__g_object_unref0_0 (self->priv->properties);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	self->priv->properties = _tmp21_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp22_ = self->priv->properties;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp23_ = g_list_length (_tmp22_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	self->empty = _tmp23_ == ((guint) 0);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp24_ = self->empty;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	if (!_tmp24_) {
#line 328 "properties-page-widget.c"
		gint current_row = 0;
		GList* _tmp25_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
		current_row = 1;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
		_tmp25_ = self->priv->properties;
#line 335 "properties-page-widget.c"
		{
			GList* property_collection = NULL;
			GList* property_it = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			property_collection = _tmp25_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			for (property_it = property_collection; property_it != NULL; property_it = property_it->next) {
#line 343 "properties-page-widget.c"
				BoxesProperty* _tmp26_ = NULL;
				BoxesProperty* property = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
				_tmp26_ = _g_object_ref0 ((BoxesProperty*) property_it->data);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
				property = _tmp26_;
#line 350 "properties-page-widget.c"
				{
					BoxesProperty* _tmp27_ = NULL;
					const gchar* _tmp28_ = NULL;
					const gchar* _tmp29_ = NULL;
					GtkWidget* widget = NULL;
					BoxesProperty* _tmp57_ = NULL;
					GtkWidget* _tmp58_ = NULL;
					GtkWidget* _tmp59_ = NULL;
					GtkWidget* _tmp60_ = NULL;
					GtkWidget* _tmp61_ = NULL;
					BoxesProperty* _tmp67_ = NULL;
					gint _tmp68_ = 0;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					_tmp27_ = property;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					_tmp28_ = boxes_property_get_description (_tmp27_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					_tmp29_ = _tmp28_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					if (_tmp29_ != NULL) {
#line 371 "properties-page-widget.c"
						GtkLabel* label_name = NULL;
						BoxesProperty* _tmp30_ = NULL;
						const gchar* _tmp31_ = NULL;
						const gchar* _tmp32_ = NULL;
						GtkLabel* _tmp33_ = NULL;
						GtkLabel* _tmp34_ = NULL;
						GtkStyleContext* _tmp35_ = NULL;
						GtkLabel* _tmp36_ = NULL;
						GtkLabel* _tmp37_ = NULL;
						GtkGrid* _tmp38_ = NULL;
						GtkLabel* _tmp39_ = NULL;
						gint _tmp40_ = 0;
						GtkWidget* widget = NULL;
						BoxesProperty* _tmp41_ = NULL;
						GtkWidget* _tmp42_ = NULL;
						GtkWidget* _tmp43_ = NULL;
						GtkWidget* _tmp44_ = NULL;
						GtkWidget* _tmp45_ = NULL;
						GtkGrid* _tmp46_ = NULL;
						GtkWidget* _tmp47_ = NULL;
						gint _tmp48_ = 0;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp30_ = property;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp31_ = boxes_property_get_description (_tmp30_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp32_ = _tmp31_;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp33_ = (GtkLabel*) gtk_label_new (_tmp32_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						g_object_ref_sink (_tmp33_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						label_name = _tmp33_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp34_ = label_name;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp35_ = gtk_widget_get_style_context ((GtkWidget*) _tmp34_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						gtk_style_context_add_class (_tmp35_, "boxes-property-name-label");
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp36_ = label_name;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						gtk_widget_set_halign ((GtkWidget*) _tmp36_, GTK_ALIGN_START);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp37_ = label_name;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						gtk_widget_set_hexpand ((GtkWidget*) _tmp37_, FALSE);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp38_ = self->priv->grid;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp39_ = label_name;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp40_ = current_row;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						gtk_grid_attach (_tmp38_, (GtkWidget*) _tmp39_, 0, _tmp40_, 1, 1);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp41_ = property;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp42_ = boxes_property_get_widget (_tmp41_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp43_ = _tmp42_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp44_ = _g_object_ref0 (_tmp43_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						widget = _tmp44_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp45_ = widget;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						gtk_widget_set_hexpand (_tmp45_, TRUE);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp46_ = self->priv->grid;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp47_ = widget;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp48_ = current_row;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						gtk_grid_attach (_tmp46_, _tmp47_, 1, _tmp48_, 1, 1);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_g_object_unref0 (widget);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_g_object_unref0 (label_name);
#line 453 "properties-page-widget.c"
					} else {
						GtkWidget* widget = NULL;
						BoxesProperty* _tmp49_ = NULL;
						GtkWidget* _tmp50_ = NULL;
						GtkWidget* _tmp51_ = NULL;
						GtkWidget* _tmp52_ = NULL;
						GtkWidget* _tmp53_ = NULL;
						GtkGrid* _tmp54_ = NULL;
						GtkWidget* _tmp55_ = NULL;
						gint _tmp56_ = 0;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp49_ = property;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp50_ = boxes_property_get_widget (_tmp49_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp51_ = _tmp50_;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp52_ = _g_object_ref0 (_tmp51_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						widget = _tmp52_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp53_ = widget;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						gtk_widget_set_hexpand (_tmp53_, TRUE);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp54_ = self->priv->grid;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp55_ = widget;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp56_ = current_row;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						gtk_grid_attach (_tmp54_, _tmp55_, 0, _tmp56_, 2, 1);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_g_object_unref0 (widget);
#line 488 "properties-page-widget.c"
					}
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					_tmp57_ = property;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					_tmp58_ = boxes_property_get_extra_widget (_tmp57_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					_tmp59_ = _tmp58_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					_tmp60_ = _g_object_ref0 (_tmp59_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					widget = _tmp60_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					_tmp61_ = widget;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					if (_tmp61_ != NULL) {
#line 504 "properties-page-widget.c"
						gint _tmp62_ = 0;
						GtkWidget* _tmp63_ = NULL;
						GtkGrid* _tmp64_ = NULL;
						GtkWidget* _tmp65_ = NULL;
						gint _tmp66_ = 0;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp62_ = current_row;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						current_row = _tmp62_ + 1;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp63_ = widget;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						gtk_widget_set_hexpand (_tmp63_, TRUE);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp64_ = self->priv->grid;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp65_ = widget;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						_tmp66_ = current_row;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
						gtk_grid_attach (_tmp64_, _tmp65_, 0, _tmp66_, 2, 1);
#line 526 "properties-page-widget.c"
					}
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					_tmp67_ = property;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					g_signal_connect_object (_tmp67_, "refresh-properties", (GCallback) ______lambda38__boxes_property_refresh_properties, self, 0);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					_tmp68_ = current_row;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					current_row = _tmp68_ + 1;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					_g_object_unref0 (widget);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
					_g_object_unref0 (property);
#line 540 "properties-page-widget.c"
				}
			}
		}
	}
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_g_object_unref0 (scrolled_win);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	return self;
#line 551 "properties-page-widget.c"
}


BoxesPropertiesPageWidget* boxes_properties_page_widget_new (BoxesPropertiesPage page, BoxesMachine* machine) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	return boxes_properties_page_widget_construct (BOXES_TYPE_PROPERTIES_PAGE_WIDGET, page, machine);
#line 558 "properties-page-widget.c"
}


gboolean boxes_properties_page_widget_flush_changes (BoxesPropertiesPageWidget* self) {
	gboolean result = FALSE;
	gboolean reboot_required = FALSE;
	GList* _tmp0_ = NULL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	reboot_required = FALSE;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_tmp0_ = self->priv->properties;
#line 572 "properties-page-widget.c"
	{
		GList* property_collection = NULL;
		GList* property_it = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
		property_collection = _tmp0_;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
		for (property_it = property_collection; property_it != NULL; property_it = property_it->next) {
#line 580 "properties-page-widget.c"
			BoxesProperty* _tmp1_ = NULL;
			BoxesProperty* property = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			_tmp1_ = _g_object_ref0 ((BoxesProperty*) property_it->data);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
			property = _tmp1_;
#line 587 "properties-page-widget.c"
			{
				BoxesProperty* _tmp2_ = NULL;
				gboolean _tmp3_ = FALSE;
				BoxesProperty* _tmp4_ = NULL;
				gboolean _tmp5_ = FALSE;
				gboolean _tmp6_ = FALSE;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
				_tmp2_ = property;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
				boxes_property_flush (_tmp2_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
				_tmp3_ = reboot_required;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
				_tmp4_ = property;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
				_tmp5_ = boxes_property_get_reboot_required (_tmp4_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
				_tmp6_ = _tmp5_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
				reboot_required = _tmp3_ | _tmp6_;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
				_g_object_unref0 (property);
#line 610 "properties-page-widget.c"
			}
		}
	}
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	result = reboot_required;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	return result;
#line 618 "properties-page-widget.c"
}


static void boxes_properties_page_widget_class_init (BoxesPropertiesPageWidgetClass * klass) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	boxes_properties_page_widget_parent_class = g_type_class_peek_parent (klass);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	g_type_class_add_private (klass, sizeof (BoxesPropertiesPageWidgetPrivate));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_properties_page_widget_finalize;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	g_signal_new ("refresh_properties", BOXES_TYPE_PROPERTIES_PAGE_WIDGET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 631 "properties-page-widget.c"
}


static void boxes_properties_page_widget_instance_init (BoxesPropertiesPageWidget * self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	self->priv = BOXES_PROPERTIES_PAGE_WIDGET_GET_PRIVATE (self);
#line 638 "properties-page-widget.c"
}


static void boxes_properties_page_widget_finalize (GObject* obj) {
	BoxesPropertiesPageWidget * self;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PROPERTIES_PAGE_WIDGET, BoxesPropertiesPageWidget);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	_g_object_unref0 (self->priv->grid);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	__g_list_free__g_object_unref0_0 (self->priv->properties);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-page-widget.vala"
	G_OBJECT_CLASS (boxes_properties_page_widget_parent_class)->finalize (obj);
#line 652 "properties-page-widget.c"
}


GType boxes_properties_page_widget_get_type (void) {
	static volatile gsize boxes_properties_page_widget_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_page_widget_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPropertiesPageWidgetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_properties_page_widget_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesPropertiesPageWidget), 0, (GInstanceInitFunc) boxes_properties_page_widget_instance_init, NULL };
		GType boxes_properties_page_widget_type_id;
		boxes_properties_page_widget_type_id = g_type_register_static (gtk_box_get_type (), "BoxesPropertiesPageWidget", &g_define_type_info, 0);
		g_once_init_leave (&boxes_properties_page_widget_type_id__volatile, boxes_properties_page_widget_type_id);
	}
	return boxes_properties_page_widget_type_id__volatile;
}



